@@ -1,6 +1,7 @@
 import logging
 import requests
 import json
+import urllib
 
 from odoo_somconnexio_python_client import helpers
 from odoo_somconnexio_python_client import exceptions
@@ -59,9 +60,8 @@ class Client(object):
         )
 
     def _format_url(self, path):
-        return "{url}{path_prefix}{path}".format(
-            url=self.baseurl, path_prefix="/api", path=path
-        )
+        path = "/api" + path
+        return urllib.parse.urljoin(self.baseurl, path)
 
     def _send_request(self, verb, url, payload=None, params={}, extra_headers={}):
         """send the API request using the *requests.request* method
