@@ -15,7 +15,7 @@ class Address:
     """
 
     def __init__(
-        self, street="", zip_code="", city="", state="", country="", street2=None
+        self, street="", zip_code="", city="", state="", country="", street2=None, **kwargs
     ):
         self.street = street
         self.street2 = street2
