@@ -3,7 +3,7 @@ from odoo_somconnexio_python_client.resources.mobile_isp_info import MobileISPIn
 
 
 class CRMLeadLine:
-    def __init__(self, product_code, broadband_isp_info=None, mobile_isp_info=None):
+    def __init__(self, product_code, broadband_isp_info=None, mobile_isp_info=None, **kwargs):
         self.product_code = product_code
         if broadband_isp_info:
             self.broadband_isp_info = BroadbandISPInfo(**broadband_isp_info)
