@@ -3,7 +3,17 @@ from odoo_somconnexio_python_client.client import Client
 
 class Product:
     def __init__(
-        self, name, code, price, category="", minutes="", data="", bandwidth="", available_for=[]
+        self,
+        name,
+        code,
+        price,
+        category="",
+        minutes="",
+        data="",
+        bandwidth="",
+        available_for=[],
+        has_landline_phone=False,
+        **kwargs
     ):
         self.code = code
         self.name = name
@@ -13,6 +23,7 @@ class Product:
         self.data = data
         self.bandwidth = bandwidth
         self.available_for = available_for
+        self.has_landline_phone = has_landline_phone
 
 
 class ProductCatalog:
